@@ -1,33 +1,47 @@
+#include <QtGui/QApplication>
 #include "despotifyplay.h"
 
 DespotifyPlay::DespotifyPlay(despotify_session* _ds,ao_device* _ao) {
+
     this->play_state = PAUSE;
     this->last_state = PAUSE;
     this->ao = _ao;
     this->ds = _ds;
+
 }
 
 void DespotifyPlay::PlayPause(void)
 {
+
     this->mutex.lock();
+
     if(this->play_state==PLAY)
         this->play_state = PAUSE;
     else
         this->play_state = PLAY;
+
     this->mutex.unlock();
 }
 
 void DespotifyPlay::NewSong(despotify_session* ds, track* t, bool play_as_list) {
+
     this->mutex.lock();
-    if(t&&t->playable) {
-        despotify_stop(ds);
-        this->usleep(250);
-        despotify_play(ds, t, play_as_list);
-        this->play_state = PLAY;
+
+    if(t) {
+        if(t->playable) {
+            despotify_stop(ds);
+            this->usleep(250);
+            despotify_play(ds, t, play_as_list);
+            this->play_state = PLAY;
+        } else {
+            this->play_state = PAUSE;
+        }
     } else {
         this->play_state = PAUSE;
     }
+
     this->mutex.unlock();
+
 }
 
 void DespotifyPlay::Pause()
@@ -60,20 +74,29 @@ void DespotifyPlay::run()
 
             this->mutex.lock();
 
+
             switch (this->play_state) {
                 case PAUSE: {
+
+                    /* Status changed to paused, set normal priority */
+                    this->setPriority(QThread::NormalPriority);
+
                     emit this->Paused();
-                    qDebug() << "Emitting 1";
+
                     break;
                 }
                 case PLAY: {
+
+                    /* Status changed to playing - increasing priority */
+                    this->setPriority(QThread::HighestPriority);
+
                     emit this->Playing();
-                    qDebug() << "Emitting 2";
+
                     break;
                 }
                 case EXIT: {
                     emit this->Exiting();
-                    qDebug() << "Emitting 3";
+
                     break;
                 }
 
@@ -88,23 +111,22 @@ void DespotifyPlay::run()
         /* Do the regular stuff... */
         switch (this->play_state) {
             case PAUSE: {
+                /* Sleep 250 ms while paused */
+                this->usleep(250);
                 break;
             }
 
             case PLAY: {
 
                 this->mutex.lock();
-                if(!this->ds->dlabort) {
-                    int rc = despotify_get_pcm(this->ds, &pcm);
-                    if (rc == 0 && pcm.len > 0) {
-                        audio_play_pcm(this->ao, &pcm);
-                    } else {
-                        qDebug() << "despotify_get_pcm() returned error " << rc;
-                        exit(-1);
-                    }
+
+                int rc = despotify_get_pcm(this->ds, &pcm);
+                if (rc == 0 && pcm.len > 0) {
+                    audio_play_pcm(this->ao, &pcm);
                 } else {
-                    qDebug() << "Skipping play due to dlabort";
+                    exit(-1);
                 }
+
                 this->mutex.unlock();
 
                 break;
@@ -116,7 +138,7 @@ void DespotifyPlay::run()
         }
 
         /* Give the system some time to think */
-        DespotifyPlay::usleep( 250 );
+        qApp->processEvents();
 
     }
 }
