@@ -15,6 +15,8 @@ MainWindow::MainWindow(QWidget *parent) :
     this->dw = new DespotifyWrap();
     qDebug() << "Is spotify initialized? " << this->dw->IsInitialized();
 
+    this->last_sec = 0;
+
     /* Connect signals */
     this->connect(this->dw, SIGNAL(PlaylistsUpdated()),this, SLOT(PlaylistsUpdated()));
     this->connect(&dc, SIGNAL(NewTrack(int,int,int,track*)),this, SLOT(NewTrack(int,int,int,track*)));
@@ -54,11 +56,6 @@ void MainWindow::changeEvent(QEvent *e)
     }
 }
 
-void MainWindow::on_pushButton_5_clicked()
-{
-
-}
-
 void MainWindow::on_pbLogin_clicked()
 {
 
@@ -100,8 +97,9 @@ void MainWindow::PlaylistsUpdated() {
 
     /* Insert all playlists in combo box */
     playlist* p = this->dw->GetPlaylists();
-    if(p!=NULL){
-        for (p; p; p = p->next)
+    if(p){
+        this->ui->cbPlaylists->addItem(tr("Select playlist"),QString("0"));
+        for (; p; p = p->next)
         {
             if(p != NULL) {
                 this->ui->cbPlaylists->addItem(QString::fromUtf8(p->name), QString::fromUtf8((char*)p->playlist_id));
@@ -110,6 +108,8 @@ void MainWindow::PlaylistsUpdated() {
                 qDebug() << "This really shouldn't happen... really...";
             }
         }
+    } else {
+        this->ui->cbPlaylists->addItem(tr("Select playlist"),QString("0"));
     }
 }
 
@@ -153,19 +153,6 @@ void MainWindow::PrintTracks() {
     }
 }
 
-void MainWindow::on_pbShowPlaylist_clicked()
-{
-    qDebug() << "Show playlist button clicked";
-    /* Iterate through all playlists */
-    for (playlist* p = this->dw->GetPlaylists(); p; p = p->next)
-    {
-        if(QString((char*)p->playlist_id) == this->ui->cbPlaylists->itemData(this->ui->cbPlaylists->currentIndex())) {
-            this->dw->pending_list = p;
-            this->PrintTracks();
-        }
-    }
-}
-
 void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
 {
     qDebug() << "Playing offset " << QString(item->text(0));
@@ -175,15 +162,6 @@ void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
     this->dw->Play(QString(item->text(0)).toInt()-1);
 }
 
-void MainWindow::on_pbSearch_clicked()
-{
-    QByteArray search = this->ui->leSearch->text().toLatin1();
-    char *c_search = search.data();
-
-    if(this->dw->Search(c_search))
-        this->PrintTracks();
-}
-
 void MainWindow::on_pushButton_4_clicked()
 {
     this->dw->PlayPrev();
@@ -194,11 +172,6 @@ void MainWindow::on_pushButton_3_clicked()
     this->dw->PlayNext();
 }
 
-void MainWindow::on_pushButton_2_clicked()
-{
-
-}
-
 void MainWindow::on_pushButton_clicked()
 {
     this->dw->player->PlayPause();
@@ -219,14 +192,18 @@ void MainWindow::EndOfPlaylist() {
 
 void MainWindow::TellTime(int min, int sec, int totsec) {
 
-    int t_min = (int)this->song_tot_len/60;
-    int t_sec = (int)this->song_tot_len%60;
+    if(this->last_sec!=totsec) {
+        int t_min = (int)this->song_tot_len/60;
+        int t_sec = (int)this->song_tot_len%60;
 
-    QString elapse;
-    elapse = QString("%1:%2 / %3:%4").arg(min,2,10,QChar('0')).arg(sec,2,10,QChar('0')).arg(t_min,2,10,QChar('0')).arg(t_sec,2,10,QChar('0'));
+        QString elapse;
+        elapse = QString("%1:%2 / %3:%4").arg(min,2,10,QChar('0')).arg(sec,2,10,QChar('0')).arg(t_min,2,10,QChar('0')).arg(t_sec,2,10,QChar('0'));
 
-    this->ui->lblElapsed->setText(elapse);
-    this->ui->hsElapsed->setValue(totsec);
+        this->ui->lblElapsed->setText(elapse);
+        this->ui->hsElapsed->setValue(totsec);
+
+        this->last_sec = totsec;
+    }
 
 }
 
@@ -242,17 +219,35 @@ void MainWindow::Exiting() {
     qDebug() << "Exiting";
 }
 
-void MainWindow::on_cbPlaylists_activated(int index)
+void MainWindow::on_cbPlaylists_currentIndexChanged(int index)
 {
 
+    qDebug() << "Show playlist button clicked";
+    /* Iterate through all playlists */
+    playlist* p = this->dw->GetPlaylists();
+    if(p) {
+        for(; p; p = p->next)
+        {
+            if(QString((char*)p->playlist_id) == this->ui->cbPlaylists->itemData(this->ui->cbPlaylists->currentIndex())) {
+                this->dw->pending_list = p;
+                this->PrintTracks();
+            }
+        }
+    }
+    this->ui->cbPlaylists->setCurrentIndex(0);
 }
 
+void MainWindow::on_leSearch_returnPressed()
+{
+    QByteArray search = this->ui->leSearch->text().toUtf8();
+    char *c_search = search.data();
+
+    if(this->dw->Search(c_search))
+        this->PrintTracks();
+
+    this->ui->leSearch->setText(QString(""));
+}
 void MainWindow::on_cbPlaylists_currentIndexChanged(QString )
 {
 
 }
-
-void MainWindow::on_cbPlaylists_currentIndexChanged(int index)
-{
-
-}
