@@ -1,50 +1,44 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="fi" sourcelanguage="en">
+<!DOCTYPE TS><TS version="1.1" language="fi">
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="20"/>
-        <source>MainWindow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="393"/>
+        <location filename="../mainwindow.ui" line="436"/>
         <source>Playlist</source>
         <translation type="unfinished">Soittolista</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="296"/>
+        <location filename="../mainwindow.ui" line="303"/>
         <source>Artist</source>
         <translation type="unfinished">Artisti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="301"/>
+        <location filename="../mainwindow.ui" line="308"/>
         <source>Album</source>
         <translation type="unfinished">Albumi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="311"/>
+        <location filename="../mainwindow.ui" line="318"/>
         <source>Rating</source>
         <translation type="unfinished">Lukema</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="398"/>
+        <location filename="../mainwindow.ui" line="441"/>
         <source>Search</source>
         <translation type="unfinished">Etsi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="403"/>
+        <location filename="../mainwindow.ui" line="446"/>
         <source>Recent</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="151"/>
+        <location filename="../mainwindow.ui" line="144"/>
         <source>Username</source>
         <translation type="unfinished">Käyttäjänimi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="161"/>
+        <location filename="../mainwindow.ui" line="158"/>
         <source>Password</source>
         <translation type="unfinished">Salasana</translation>
     </message>
@@ -56,28 +50,43 @@
     <message>
         <location filename="../mainwindow.ui" line="276"/>
         <source>Show</source>
-        <translation type="unfinished">Näytä</translation>
+        <translation type="obsolete">Näytä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="291"/>
+        <location filename="../mainwindow.ui" line="298"/>
         <source>Title</source>
         <translation type="unfinished">Kappaleen nimi</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="306"/>
+        <location filename="../mainwindow.ui" line="313"/>
         <source>Duration</source>
         <translation type="unfinished">Kesto</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="334"/>
         <source>Play/Pause</source>
-        <translation type="unfinished">Play/Pause</translation>
+        <translation type="obsolete">Play/Pause</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="57"/>
+        <location filename="../mainwindow.cpp" line="75"/>
         <source>Incorrect credentials entered
 please try again.</source>
         <translation type="unfinished">Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="70"/>
+        <source>Authenticating...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="81"/>
+        <source>Updating playlists...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="112"/>
+        <source>Select playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
